SystemOrganization addCategory: #'PharoBot-Environment'!
SystemOrganization addCategory: #'PharoBot-Environment-Tests'!

Exception subclass: #PharoBotEnvironmentError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotEnvironmentError commentStamp: '<historical>' prior: 0!
I represent an error occurred in the process of loading a class, exporting a class, removing methods, and so on.!

!PharoBotEnvironmentError class methodsFor: 'messages' stamp: 'NahuelGarbezza 7/14/2012 22:02'!
attemptToAddRobotClass

	^'No se puede agregar la clase Robot. Ya existe en el entorno.'! !

!PharoBotEnvironmentError class methodsFor: 'messages' stamp: 'NahuelGarbezza 7/14/2012 22:50'!
attemptToRemoveInexistentClass

	^'La clase no existe'! !

!PharoBotEnvironmentError class methodsFor: 'messages' stamp: 'NahuelGarbezza 7/14/2012 22:44'!
cannotRemoveRobotClass
	
	^'No puede eliminarse la clase Robot'! !

!PharoBotEnvironmentError class methodsFor: 'signaling' stamp: 'NahuelGarbezza 7/14/2012 22:13'!
signalAttemptToAddRobotClass

	self signal: self attemptToAddRobotClass! !

!PharoBotEnvironmentError class methodsFor: 'signaling' stamp: 'NahuelGarbezza 7/14/2012 22:50'!
signalAttemptToRemoveInexistentClass

	self signal: self attemptToRemoveInexistentClass! !

!PharoBotEnvironmentError class methodsFor: 'signaling' stamp: 'NahuelGarbezza 7/14/2012 22:50'!
signalCannotRemoveRobotClass

	self signal: self cannotRemoveRobotClass! !

Announcement subclass: #PharoBotWorkspaceAddedEvent
	instanceVariableNames: 'workspace'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotWorkspaceAddedEvent methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/27/2012 23:48'!
workspace

	^workspace! !

!PharoBotWorkspaceAddedEvent methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/28/2012 22:21'!
workspace: aWorkspace

	workspace := aWorkspace! !

Announcement subclass: #PharoBotWorkspaceRemovedEvent
	instanceVariableNames: 'workspace'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotWorkspaceRemovedEvent methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/28/2012 22:21'!
workspace

	^workspace! !

!PharoBotWorkspaceRemovedEvent methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/28/2012 22:21'!
workspace: aWorkspace

	workspace := aWorkspace! !

TestCase subclass: #PharoBotGlobalEnvironmentTest
	instanceVariableNames: 'env'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment-Tests'!

!PharoBotGlobalEnvironmentTest commentStamp: '<historical>' prior: 0!
A PharoBotGlobalEnvironmentTest is a test class for testing the behavior of PharoBotGlobalEnvironment!

!PharoBotGlobalEnvironmentTest methodsFor: 'set up' stamp: 'NahuelGarbezza 7/14/2012 22:27'!
setUp

	PharoBotGlobalEnvironment clearInstance.
	env := PharoBotGlobalEnvironment instance.! !

!PharoBotGlobalEnvironmentTest methodsFor: 'set up' stamp: 'NahuelGarbezza 7/14/2012 22:29'!
tearDown

	(Smalltalk at: self tempClassName ifAbsent: [^self]) removeFromSystem! !

!PharoBotGlobalEnvironmentTest methodsFor: 'set up' stamp: 'NahuelGarbezza 7/14/2012 22:20'!
tempClassName

	^#PharoBotTempClass! !

!PharoBotGlobalEnvironmentTest methodsFor: 'adding classes' stamp: 'NahuelGarbezza 7/18/2012 17:33'!
testAddRobotClassShouldFailBecauseItIsDefault

	self
		should: [ env addClassNamed: #Robot ]
		raise: PharoBotEnvironmentError
		withExceptionDo: [ :e |
			self assert: e messageText = PharoBotEnvironmentError attemptToAddRobotClass ]! !

!PharoBotGlobalEnvironmentTest methodsFor: 'adding classes' stamp: 'NahuelGarbezza 7/14/2012 22:22'!
testAddingANewClass
	
	env addClassNamed: self tempClassName.
	
	self assert: (env hasClassNamed: self tempClassName).! !

!PharoBotGlobalEnvironmentTest methodsFor: 'adding classes' stamp: 'NahuelGarbezza 7/14/2012 22:28'!
testAddingANewClassIsCreatedInTheImage
	
	env addClassNamed: self tempClassName.
	
	self shouldnt: (Smalltalk at: self tempClassName) raise: Error.! !

!PharoBotGlobalEnvironmentTest methodsFor: 'accessing classes' stamp: 'NahuelGarbezza 7/14/2012 22:07'!
testDoesntHaveAClassName

	self deny: (PharoBotGlobalEnvironment instance hasClassNamed: #NonExistentClassXXX)! !

!PharoBotGlobalEnvironmentTest methodsFor: 'accessing classes' stamp: 'NahuelGarbezza 7/14/2012 22:22'!
testEnvironmentHasRobotClassByDefault

	self assert: (env hasClassNamed: #Robot)! !

!PharoBotGlobalEnvironmentTest methodsFor: 'singleton' stamp: 'NahuelGarbezza 7/14/2012 21:54'!
testGlobalEnvironmentIsSingleton

	self assert: PharoBotGlobalEnvironment instance == PharoBotGlobalEnvironment instance! !

!PharoBotGlobalEnvironmentTest methodsFor: 'accessing classes' stamp: 'NahuelGarbezza 8/20/2012 20:02'!
testItReturnClasses

	self assert: {Robot} asSet equals: env classes! !

!PharoBotGlobalEnvironmentTest methodsFor: 'adding classes' stamp: 'NahuelGarbezza 7/14/2012 22:31'!
testNewClassAddedInTheImageShouldExtendFromObject
	
	env addClassNamed: self tempClassName.
	
	self assert: (Smalltalk at: self tempClassName) superclass = Object.! !

!PharoBotGlobalEnvironmentTest methodsFor: 'removing classes' stamp: 'NahuelGarbezza 7/14/2012 22:49'!
testRemoveAClassInexistentShouldRaiseAnError

	self
		should: [ env removeClassNamed: self tempClassName ]
		raise: PharoBotEnvironmentError 
		withExceptionDo: [ :e | self assert: e messageText = PharoBotEnvironmentError attemptToRemoveInexistentClass  ]! !

!PharoBotGlobalEnvironmentTest methodsFor: 'removing classes' stamp: 'NahuelGarbezza 7/14/2012 22:54'!
testRemoveAClassRecentlyAdded

	env addClassNamed: self tempClassName.
	env removeClassNamed: self tempClassName.
	
	self deny: (env hasClassNamed: self tempClassName)! !

!PharoBotGlobalEnvironmentTest methodsFor: 'removing classes' stamp: 'NahuelGarbezza 7/14/2012 23:03'!
testRemoveAClassRecentlyAddedAlsoShouldRemoveItFromTheImage

	env addClassNamed: self tempClassName.
	env removeClassNamed: self tempClassName.
	
	self should: [ Smalltalk at: self tempClassName ] raise: Error.! !

!PharoBotGlobalEnvironmentTest methodsFor: 'removing classes' stamp: 'NahuelGarbezza 7/14/2012 22:44'!
testRobotClassCannotBeRemoved

	self
		should: [ env removeClassNamed: #Robot ]
		raise: PharoBotEnvironmentError
		withExceptionDo: [ :e |
			self assert: e messageText = PharoBotEnvironmentError cannotRemoveRobotClass ]! !

Announcer subclass: #PharoBotEnvironment
	instanceVariableNames: 'workspaces'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotEnvironment commentStamp: 'NahuelGarbezza 4/7/2012 17:49' prior: 0!
Contiene configuraciones basicas para iniciar un entorno de PharoBot, como por ejemplo los workspaces.!

!PharoBotEnvironment methodsFor: 'actions' stamp: 'NahuelGarbezza 8/27/2012 23:47'!
addWorkspace: aWorkspace

	self workspaces add: aWorkspace.
	self announce: (PharoBotWorkspaceAddedEvent new workspace: aWorkspace).! !

!PharoBotEnvironment methodsFor: 'constants' stamp: 'NahuelGarbezza 4/7/2012 17:32'!
defaultVariableBindings

	^{}! !

!PharoBotEnvironment methodsFor: 'initialize-release' stamp: 'NahuelGarbezza 8/27/2012 23:53'!
initialize

	super initialize.
	workspaces := OrderedCollection with: self startWorkspace.! !

!PharoBotEnvironment methodsFor: 'actions' stamp: 'NahuelGarbezza 8/28/2012 22:20'!
removeWorkspace: aWorkspace

	self workspaces remove: aWorkspace.
	self announce: (PharoBotWorkspaceRemovedEvent new workspace: aWorkspace).! !

!PharoBotEnvironment methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/8/2012 09:16'!
workspaces

	^workspaces! !

PharoBotEnvironment subclass: #PharoBotEnvironmentWithClasses
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotEnvironmentWithClasses methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/21/2012 00:23'!
classMethodsFor: aClass inCategory: category
	
	self flag: #todo.
	^#()! !

!PharoBotEnvironmentWithClasses methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/21/2012 00:07'!
classes

	^PharoBotGlobalEnvironment instance classes! !

!PharoBotEnvironmentWithClasses methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/21/2012 00:23'!
instanceMethodsFor: aClass inCategory: category

	self flag: #todo.
	^#()! !

!PharoBotEnvironmentWithClasses methodsFor: 'constants' stamp: 'NahuelGarbezza 8/20/2012 19:56'!
startWorkspace

	^PharoBotWorkspace new
		title: 'Bienvenido a PharoBot - Practica 2'! !

PharoBotEnvironment subclass: #PharoBotEnvironmentWithObjects
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotEnvironmentWithObjects methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/20/2012 19:44'!
categories

	^self robotClass protocols! !

!PharoBotEnvironmentWithObjects methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/20/2012 19:44'!
defaultVariableBindings

	^{ #robotech -> self robotClass new }! !

!PharoBotEnvironmentWithObjects methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/20/2012 19:43'!
robotClass

	^PharoBotGlobalEnvironment instance robotClass! !

!PharoBotEnvironmentWithObjects methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/20/2012 19:43'!
robotMethods

	^self robotClass selectors! !

!PharoBotEnvironmentWithObjects methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/20/2012 19:44'!
robotMethodsInCategory: category

	^self robotClass selectors
		select: [ :sel | (self robotClass >> sel) category == category ]! !

!PharoBotEnvironmentWithObjects methodsFor: 'constants' stamp: 'NahuelGarbezza 2/27/2012 11:14'!
startWorkspace

	^PharoBotWorkspace new
		title: 'Bienvenido a PharoBot - Clase 1';
		content:
'
"Bienvenido a PharoBot - Clase 1"

robotech mover: 100.
robotech norte.

etc, etc, etc...
';
	variableBindings: self defaultVariableBindings asDictionary;
	yourself! !

Object subclass: #PharoBotGlobalEnvironment
	instanceVariableNames: 'classNames'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

PharoBotGlobalEnvironment class
	instanceVariableNames: 'instance'!

!PharoBotGlobalEnvironment commentStamp: '<historical>' prior: 0!
I am responsible of keep track of changes that affects the image (new classes, new methods, etc).!

PharoBotGlobalEnvironment class
	instanceVariableNames: 'instance'!

!PharoBotGlobalEnvironment class methodsFor: 'singleton' stamp: 'NahuelGarbezza 7/14/2012 21:52'!
clearInstance

	instance := nil! !

!PharoBotGlobalEnvironment class methodsFor: 'singleton' stamp: 'NahuelGarbezza 7/14/2012 21:57'!
instance

	^instance := instance ifNil: [ super new ]! !

!PharoBotGlobalEnvironment methodsFor: 'defining classes and methods' stamp: 'NahuelGarbezza 7/18/2012 17:32'!
addClassNamed: aClassName

	aClassName == self robotClassName
		ifTrue: [ PharoBotEnvironmentError signalAttemptToAddRobotClass ].
	
	self createClass: aClassName.
	self classNames add: aClassName! !

!PharoBotGlobalEnvironment methodsFor: 'defining classes and methods' stamp: 'NahuelGarbezza 7/18/2012 17:21'!
addRobotClass

	self classNames add: self robotClassName! !

!PharoBotGlobalEnvironment methodsFor: 'accessing' stamp: 'NahuelGarbezza 7/14/2012 22:08'!
classNames

	^classNames! !

!PharoBotGlobalEnvironment methodsFor: 'accessing' stamp: 'NahuelGarbezza 7/14/2012 22:10'!
classNames: aSet 

	classNames := aSet! !

!PharoBotGlobalEnvironment methodsFor: 'accessing' stamp: 'NahuelGarbezza 8/20/2012 20:01'!
classes

	^self classNames collect: [ :className |
		Smalltalk at: className ifAbsent: [ PharoBotEnvironmentError signal ] ]! !

!PharoBotGlobalEnvironment methodsFor: 'private' stamp: 'NahuelGarbezza 7/14/2012 22:34'!
createClass: aClassName

	Object subclass: aClassName
		instanceVariableNames: ''
		classVariableNames: ''
		poolDictionaries: ''
		category: 'PharoBot-Environment'! !

!PharoBotGlobalEnvironment methodsFor: 'querying' stamp: 'NahuelGarbezza 7/14/2012 22:07'!
hasClassNamed: aClassName

	^self classNames includes: aClassName! !

!PharoBotGlobalEnvironment methodsFor: 'initialize-release' stamp: 'NahuelGarbezza 7/14/2012 22:09'!
initialize

	self classNames: Set new.
	self addRobotClass.! !

!PharoBotGlobalEnvironment methodsFor: 'private' stamp: 'NahuelGarbezza 7/14/2012 22:57'!
removeClass: aClassName

	(Smalltalk at: aClassName) removeFromSystem! !

!PharoBotGlobalEnvironment methodsFor: 'defining classes and methods' stamp: 'NahuelGarbezza 7/18/2012 17:32'!
removeClassNamed: aClassName

	aClassName == self robotClassName
		ifTrue: [ PharoBotEnvironmentError signalCannotRemoveRobotClass ].
	
	self classNames
		remove: aClassName
		ifAbsent: [ PharoBotEnvironmentError signalAttemptToRemoveInexistentClass ].
	self removeClass: aClassName.! !

!PharoBotGlobalEnvironment methodsFor: 'constants' stamp: 'NahuelGarbezza 7/18/2012 17:38'!
robotClass

	^Smalltalk at: self robotClassName ifAbsent: [ PharoBotEnvironmentError signal ]! !

!PharoBotGlobalEnvironment methodsFor: 'constants' stamp: 'NahuelGarbezza 7/18/2012 17:20'!
robotClassName

	^#Robot! !

Object subclass: #PharoBotWorkspace
	instanceVariableNames: 'title content variableBindings'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'PharoBot-Environment'!

!PharoBotWorkspace commentStamp: '<historical>' prior: 0!
I am a PharoBot workspace, I have a title, the content (code) and the variables defined with each corresponding value.!

!PharoBotWorkspace methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/7/2012 17:29'!
content

	^content! !

!PharoBotWorkspace methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/7/2012 17:29'!
content: anObject

	content := anObject! !

!PharoBotWorkspace methodsFor: 'testing' stamp: 'NahuelGarbezza 7/31/2012 13:28'!
hasBindingOf: aString

	^self variableBindings includesKey: aString! !

!PharoBotWorkspace methodsFor: 'initialize-release' stamp: 'NahuelGarbezza 7/29/2012 22:17'!
initialize

	self initializeBindings! !

!PharoBotWorkspace methodsFor: 'initialize-release' stamp: 'NahuelGarbezza 7/29/2012 22:18'!
initializeBindings

	variableBindings := Dictionary new.! !

!PharoBotWorkspace methodsFor: 'printing' stamp: 'NahuelGarbezza 2/11/2012 17:04'!
printOn: aStream

	aStream << self title! !

!PharoBotWorkspace methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/7/2012 17:29'!
title

	^title! !

!PharoBotWorkspace methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/7/2012 17:29'!
title: anObject

	title := anObject! !

!PharoBotWorkspace methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/7/2012 17:29'!
variableBindings

	^variableBindings! !

!PharoBotWorkspace methodsFor: 'accessing' stamp: 'NahuelGarbezza 4/7/2012 17:29'!
variableBindings: anObject

	variableBindings := anObject! !
